# `fica` 

[![PyPI](https://img.shields.io/pypi/v/fica.svg)](https://pypi.org/project/fica/)
[![Run tests](https://github.com/chrispyles/fica/actions/workflows/run-tests.yml/badge.svg)](https://github.com/chrispyles/fica/actions/workflows/run-tests.yml)
[![codecov](https://codecov.io/gh/chrispyles/fica/branch/main/graph/badge.svg?token=67BKRAXF7T)](https://codecov.io/gh/chrispyles/fica)
[![Documentation Status](https://readthedocs.org/projects/fica/badge/?version=latest)](https://fica.readthedocs.io/en/latest/?badge=latest)

<p align="center">
  <img src="images/logo.svg" />
</p>

`fica` is a Python library for managing and documenting the structure of user-specified
configurations. With it, you can create dictionaries of configurations that contain default values
and descriptions for easily configuring applications with user input and documenting available
configurations and their defaults.

`fica` is compatible with Python 3.9+.


## Documentation

You can find the documentation for `fica` [here](https://fica.readthedocs.io/).


## Contributing

See [`CONTRIBUTING.md`](CONTRIBUTING.md).


## Changelog

See [`CHANGELOG.md`](CHANGELOG.md).
